systemtools.IOManager
=====================

.. abjad-lineage:: abjad.tools.systemtools.IOManager.IOManager

.. autoclass:: abjad.tools.systemtools.IOManager.IOManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.IOManager.IOManager.clear_terminal
      ~abjad.tools.systemtools.IOManager.IOManager.count_function_calls
      ~abjad.tools.systemtools.IOManager.IOManager.find_executable
      ~abjad.tools.systemtools.IOManager.IOManager.get_last_output_file_name
      ~abjad.tools.systemtools.IOManager.IOManager.get_next_output_file_name
      ~abjad.tools.systemtools.IOManager.IOManager.make_subprocess
      ~abjad.tools.systemtools.IOManager.IOManager.open_file
      ~abjad.tools.systemtools.IOManager.IOManager.open_last_log
      ~abjad.tools.systemtools.IOManager.IOManager.open_last_ly
      ~abjad.tools.systemtools.IOManager.IOManager.open_last_pdf
      ~abjad.tools.systemtools.IOManager.IOManager.profile_expr
      ~abjad.tools.systemtools.IOManager.IOManager.run_lilypond
      ~abjad.tools.systemtools.IOManager.IOManager.save_last_ly_as
      ~abjad.tools.systemtools.IOManager.IOManager.save_last_pdf_as
      ~abjad.tools.systemtools.IOManager.IOManager.spawn_subprocess

Bases
-----

- :py:class:`__builtin__.object <object>`

Static methods
--------------

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.clear_terminal
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.count_function_calls
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.find_executable
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.get_last_output_file_name
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.get_next_output_file_name
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.make_subprocess
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.open_file
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.open_last_log
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.open_last_ly
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.open_last_pdf
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.profile_expr
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.run_lilypond
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.save_last_ly_as
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.save_last_pdf_as
   :noindex:

.. automethod:: abjad.tools.systemtools.IOManager.IOManager.spawn_subprocess
   :noindex:
